/* $Workfile: OtxTemux.h $   $Revision: 1 $    $Modtime: 3/08/10 12:06p $  */
#ifndef OTX_TEMUX_H
#define OTX_TEMUX_H
/*******************************************************************************

  @doc PublicHwApi OtxTemux

  Copyright (C) 2010 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxTemux | OTX Logical Device Function Prototypes for Temux SONET/SDH devices

  @contents2
  OtxTemux.h |

  @index func | OtxTemux

  @contents2
  OTX Temux SONET/SDH Interface Device Functions - OtxTemuxXXX() | 
  Functions available for Temux physical devices hosted by Godar boards

  @head3 OtxTemuxXXX() Function Reference |

  @index func | OtxTemux

*******************************************************************************/

#include "OtxType.h"
#include "OtxDef.h"

#include "OtxTemuxD.h"
#include "OtxDataD.h"


#ifdef __cplusplus
extern "C" {
#endif


/*******************************************************************************

  @func
    Configure the Temux 336/168 device using a device configuration function.

  @comm
    The default configuration for the Temux device is used during system
    initialization. It can also be used to reconfigure the device to the
    default setting. The additional configurations are also provided to
    support additional configurations of the entire device.

  @ex |

  @xref
    <t OtxTemuxDeviceConfigurationE>


*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxDeviceCfg(
  IN OTX_HANDLE                   hDevice, // @parm A handle to a Temux device.
  IN OtxTemuxDeviceConfigurationE eCfg     // @parm Device configuration 
);

/*******************************************************************************

  @func
    SONET/SDH Subsystem configuration on the Temux 336/168 setting 
    STSI switch configuration. This function configures the 4 STS-3 
    rate input streams for an STS-12 rate output stream. This 
    function changes the data path through the STSI.

  @comm
    This function maps source data for the specified destination port.
    The function will allow up to 4 x STS-3 rate sources to be selected 
    from any of the four source ports.

  @ex |


  @xref
    <t OtxTemuxDestPortE>
    <t OtxTemuxSourcePortE>


*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxStsiDestPortCfg(
  IN OTX_HANDLE          hDevice,  // @parm A handle to a Temux device.
  IN OtxTemuxDestPortE   eDest,    // @parm Destination port 
  IN OtxTemuxSrcPortE    *pSource  // @parm 4 source STS-3 for each destination 
                                   // STS-3 within destPort
                                   // <nl> sourcePort[0] - destPort STS-3 #1
                                   // <nl> sourcePort[1] - destPort STS-3 #2
                                   // <nl> sourcePort[2] - destPort STS-3 #3
                                   // <nl> sourcePort[3] - destPort STS-3 #4
);

/*******************************************************************************

  @func
    SONET/SDH Subsystem configuration on the Temux 336/168 this function 
    sets one of the MSU Lite blocks to Telecombus switching or bypass mode.

  @comm
    When Telecombus switching mode is selected, the MSU Lite is not in a 
    state to pass data. In order for data to be passed, the MSU Lite column 
    switch must be configured. When bypass mode is selected data will pass 
    through the MSU Lite blocks.

  @ex |

  @xref
    <t OtxTemuxBlockTypeE>
    <t OtxTemuxBlockModeE>


*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxMsuCfg(
  IN OTX_HANDLE         hDevice,    // @parm A handle to a Temux device.
  IN OtxTemuxBlockTypeE eBlockType, // @parm MSU lite block type 
  IN OtxTemuxBlockModeE eBlockMode  // @parm MSU lite block mode 
);

/*******************************************************************************

  @func
    SONET/SDH Subsystem configuration on the Temux 336/168 this function 
    configures the device for the type of physical interface used on the 
    working and protect line side interfaces. It will set the device to 
    use up to 4 x OC-3/STM-1 or 1 OC-12/STM-4 physical links.

  @comm
    
  @ex |

  @xref
    <t OtxTemuxIntfModeE>


*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxSonetIntfCfg(
  IN OTX_HANDLE      hDevice,  // @parm A handle to a Temux device.
  OtxTemuxIntfModeE  eIntfMode // @parm 4 x OC-3/STM-1 or 1 x OC-12/STM-4 
);

/*******************************************************************************

  @func
    SONET/SDH Subsystem configuration on the Temux 336/168 this function 
    initializes the DCRU_622 and JAT_622E blocks.

  @comm
    Both working and protect DCRU_622 and JAT_622E blocks will be initialized 
    for each call of this function.

  @ex |

  @xref


*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxSonetClockCfg(
  IN OTX_HANDLE  hDevice, // @parm A handle to a Temux device.
  IN OTX_UINT32  nLink    // @parm One x OC-12/STM-4 operation mode: 
                          //<nl>   1   STS-12/STM-4
                          //<nl> Four x OC-3/STM-1 operation mode:  
                          //<nl>   1   STM-1/STS-3 #1 
                          //<nl>   2   STM-1/STS-3 #2 
                          //<nl>   3   STM-1/STS-3 #3 
                          //<nl>   4   STM-1/STS-3 #4

);

/*******************************************************************************

  @func
    SONET/SDH Subsystem configuration on the Temux 336/168 this function 
    enables and disables the working or protect transmit and receive 
    line interface LVDS signal pin.

  @comm

  @ex |

  @xref
    <t OtxTemuxLinkSrcE>


*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxSonetLinkCfg(
  IN OTX_HANDLE         hDevice,  // @parm A handle to a Temux device.
  IN OtxTemuxLinkSrcE   eLinkSrc, // @parm use working or protect link as source
  IN OTX_UINT32         nLink,    // @parm One x OC-12/STM-4 operation mode: 
                                  //<nl>   1   STS-12/STM-4
                                  //<nl> Four x OC-3/STM-1 operation mode:  
                                  //<nl>   1   STM-1/STS-3 #1 
                                  //<nl>   2   STM-1/STS-3 #2 
                                  //<nl>   3   STM-1/STS-3 #3 
                                  //<nl>   4   STM-1/STS-3 #4
  IN OTX_BOOL           bEnable  // @parm 0-disabled; 1-enabled
);


/*******************************************************************************

  @func
    SONET/SDH Subsystem configuration on the Temux 336/168 this function 
    specifies the type of payload contained on the OC-12/STM-4 physical 
    link or one of the 4 OC-3/STM-1 physical links.

  @comm
    Note: <nl>(1)
          For OC-12 configured for 4 x STS-3 payload, the nlink parameter 
          refers to the STM-1/STS-3 number.

          (2)
          If link 1 is used in 4 x OC-3 operation mode, sts12Concatenation 
          must be set to 0. The argument error checking will not identify 
          this case

  @ex |

  @xref


*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxSonetPayloadCfg(
  IN OTX_HANDLE   hDevice,            // @parm A handle to a Temux device.
  IN OTX_UINT32   nLink,              // @parm One x OC-12/STM-4 operation mode: 
                                      //<nl>   1   STS-12/STM-4
                                      //<nl> Four x OC-3/STM-1 operation mode:  
                                      //<nl>   1   STM-1/STS-3 #1 
                                      //<nl>   2   STM-1/STS-3 #2 
                                      //<nl>   3   STM-1/STS-3 #3 
                                      //<nl>   4   STM-1/STS-3 #4
  IN OTX_UINT32   nSts12Concatenation,// @parm STS12 Concatenation
                                      //<nl> For Four x OC-3 Operation Mode or 
                                      //<nl> 1 x OC-12 with 4 x STS-3 payload
                                      //<nl>   0 Four x STS-3/AUG-1
                                      //<nl>   1 STS-12c/AU4-4c
  IN OTX_UINT32   nSts3Concatenation  // @parm STS3 Concatenation
                                      //<nl>   0 Four x STS-3/AUG-1
                                      //<nl>   1 STS-12c/AU4-4c
                                      //<nl> For 1 x OC-12 with STS-12c payload:
                                      //<nl>   This is a don't care

);

/*******************************************************************************

  @func
    SONET/SDH Subsystem configuration on the Temux 336/168 this function 
    will configure the timing mode used by both the working and protect 
    physical link.

  @comm
    Note: <nl>(1)
          Some fileds of Protect JAT only need to be configured once as 
          part of initialization. This code uses SW SCRATCH REGISTER to 
          allow config of protect JAT blocks to only be applied once for 
          each JAT.

          (2)
          Protect JAT in loop timing mode may experience FIFO_ERR_I, 
          refer to function ProtJatFifoErrService in for recovery 
          procedure.

          (3)
          Protect JAT configuration can be removed for hardware that 
          does not physically use the Protect Optical ports.

  @ex |

  @xref
    <t OtxTemuxClockSrcE>
    <t OtxBrdSetClocks>


*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxSonetTimingCfg(
  IN OTX_HANDLE        hDevice,  // @parm A handle to a Temux device.
  IN OTX_UINT32        nLink,    // @parm One x OC-12/STM-4 operation mode: 
                                 //<nl>   1   STS-12/STM-4
                                 //<nl> Four x OC-3/STM-1 operation mode:  
                                 //<nl>   1   STM-1/STS-3 #1 
                                 //<nl>   2   STM-1/STS-3 #2 
                                 //<nl>   3   STM-1/STS-3 #3 
                                 //<nl>   4   STM-1/STS-3 #4
  IN OtxTemuxClockSrcE eClkSrc   //@parm Clock source for SONET/SDH interface
);


/*******************************************************************************

  @func
    SONET/SDH Subsystem configuration on the Temux 336/168 this function
    configures the working or protect link as the data source for the 
    ingress APS subsystem

  @comm
    The 

  @ex |

  @xref
    <t OtxTemuxDataLinkSrcE>


*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxSonetDataPathCfg(
  IN OTX_HANDLE         hDevice,    // @parm A handle to a Temux device.
  IN OTX_UINT32         nLink,      // @parm One x OC-12/STM-4 operation mode: 
                                    //<nl>   1   STS-12/STM-4
                                    //<nl> Four x OC-3/STM-1 operation mode:  
                                    //<nl>   1   STM-1/STS-3 #1 
                                    //<nl>   2   STM-1/STS-3 #2 
                                    //<nl>   3   STM-1/STS-3 #3 
                                    //<nl>   4   STM-1/STS-3 #4
  IN OtxTemuxDataLinkSrcE eLinkSrc  // @parm working or protect link as source
);

/*******************************************************************************

  @func
    SONET/SDH Subsystem configuration on the Temux 336/168 this function 
    configures the global settings associated with HOPP, LOPP and LOPP_TX 
    subsystems.

  @comm

  @ex |

  @xref


*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxHoLoPtrCfg(
  IN OTX_HANDLE  hDevice, // @parm A handle to a Temux device.
  IN OTX_UINT32  nTimeout // @parm Command timeout in milliseconds 
);

/*******************************************************************************

  @func
    SONET/SDH Subsystem configuration on the Temux 336/168 this function 
    configures the HOPP, LOPP and LOPP_TX subsystems STS-12/STM-4 payload
    type.

  @comm

  @ex |

  @xref
    <t OtxTemuxSts12PayloadE>


*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxSts12PayloadCfg(
  IN OTX_HANDLE             hDevice,       // @parm A handle to a Temux device.
  IN OtxTemuxSts12PayloadE  eSts12Payload  // @parm STS-12 configuration
);

/*******************************************************************************

  @func
    SONET/SDH Subsystem configuration on the Temux 336/168 this function 
    configures the HOPP, LOPP and LOPP_TX subsystems STS-3/AUG-1 payload
    type. Refer to Section 6.6.3 STS-3 or AUG-1 Configuration of the 
    Configuration Guide for details on the fields set by this function.

    The input parameters are the STSI HOPP input and output data streams (link) 
    and the STS-3/AUG-1 payload type (sts3Payload). The link parameter has a 
    valid range of 1 to 4. This range corresponds to the STSI HOPP input and 
    output data steams for STS-3/STM-1 number 1 to 4.

  @comm
    This function requires that the TMSU and RMSU blocks are in bypass.  
    Should TMSU and RMSU blocks be taken out of bypass mode for the purpose 
    of performing AU-3 to AU-4 conversion the *TUG3[n] bits will need to be
    reconfigured appropriately.

  @ex |

  @xref
    <t OtxTemuxSts3PayloadE>


*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxSts3PayloadCfg(
  IN OTX_HANDLE            hDevice,      // @parm A handle to a Temux device.
  IN OTX_UINT32            nLink,        // @parm Link Slice 1-4
                                         //<nl>  1   STSI HOPP STS-3/STM-1 #1  
                                         //<nl>  2   STSI HOPP STS-3/STM-1 #2 
                                         //<nl>  3   STSI HOPP STS-3/STM-1 #3 
                                         //<nl>  4   STSI HOPP STS-3/STM-1 #4
  IN OtxTemuxSts3PayloadE  eSts3Payload  // @parm STS-3 configuration
);

/*******************************************************************************

  @func
    SONET/SDH Subsystem configuration on the Temux 336/168 this function 
    configures the HOPP, LOPP and LOPP_TX subsystems STS-3c/AU-4 payload
    type.

  @comm
    The BMUX_STS1_SEL[n] bits associated with the STS-3 will be set to 1.

  @ex |

  @xref
    <t OtxTemuxSts3cPayloadE>


*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxSts3cPayloadCfg(
  IN OTX_HANDLE             hDevice,       // @parm A handle to a Temux device.
  IN OTX_UINT32             nLink,         // @parm Link Slice 1-4
                                           //<nl>  1   STSI HOPP STS-3/STM-1 #1  
                                           //<nl>  2   STSI HOPP STS-3/STM-1 #2 
                                           //<nl>  3   STSI HOPP STS-3/STM-1 #3 
                                           //<nl>  4   STSI HOPP STS-3/STM-1 #4
  IN OtxTemuxSts3cPayloadE  eSts3cPayload  // @parm STS-3C configuration
);

/*******************************************************************************

  @func
    SONET/SDH Subsystem configuration on the Temux 336/168 this function 
    configures the HOPP, LOPP and LOPP_TX subsystems STS-1 payload type.

  @comm
    The BMUX_STS1_SEL[n] bit associated with the STS-1 will be set to 0 
    for Vt-Group payload or set to 1 for C-3 payload.
  @ex |

  @xref
    <t OtxTemuxSts1PayloadE>


*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxSts1PayloadCfg(
  IN OTX_HANDLE            hDevice,      // @parm A handle to a Temux device.
  IN OTX_UINT32            nLink,        // @parm Link Slice 1-4
                                         //<nl>  1   STSI HOPP STS-3/STM-1 #1  
                                         //<nl>  2   STSI HOPP STS-3/STM-1 #2 
                                         //<nl>  3   STSI HOPP STS-3/STM-1 #3 
                                         //<nl>  4   STSI HOPP STS-3/STM-1 #4
  IN OTX_UINT32            nSts1Number,  // @parm STS number 1-3 
  IN OtxTemuxSts1PayloadE  eSts1Payload  // @parm STS1 configuration 
);

/*******************************************************************************

  @func
    SONET/SDH Subsystem configuration on the Temux 336/168 this function 
    configures the HOPP, LOPP and LOPP_TX subsystems TUG-3 payload type.

  @comm
    The TVTPA_BYP[n] bit associated with the TUG-3 will be set to 1 if 
    the payload is TU-3 -> C-3. 

  @ex |

  @xref
    <t OtxTemuxTug3PayloadE>


*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxTug3PayloadCfg(
  IN OTX_HANDLE            hDevice,      // @parm A handle to a Temux device.
  IN OTX_UINT32            nLink,        // @parm Link Slice 1-4
                                         //<nl>  1   STSI HOPP STS-3/STM-1 #1  
                                         //<nl>  2   STSI HOPP STS-3/STM-1 #2 
                                         //<nl>  3   STSI HOPP STS-3/STM-1 #3 
                                         //<nl>  4   STSI HOPP STS-3/STM-1 #4
  IN OTX_UINT32            nTug3Number,  // @parm TUG3 number 1-3 
  IN OtxTemuxTug3PayloadE  eTug3Payload  // @parm TUG3 configuration 
);

/*******************************************************************************

  @func
    SONET/SDH Subsystem configuration on the Temux 336/168 This function 
    configures the LOPP and LOPP_TX subsystems TUG-2 payload type.

  @comm

  @ex |

  @xref
    <t OtxTemuxTug2PayloadE>


*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxTug2PayloadCfg(
  IN OTX_HANDLE            hDevice,      // @parm A handle to a Temux device.
  IN OTX_UINT32            nLink,        // @parm Link Slice 1-4
                                         //<nl>  1   STSI HOPP STS-3/STM-1 #1  
                                         //<nl>  2   STSI HOPP STS-3/STM-1 #2 
                                         //<nl>  3   STSI HOPP STS-3/STM-1 #3 
                                         //<nl>  4   STSI HOPP STS-3/STM-1 #4
  IN OTX_UINT32            nTug3Number,  // @parm TUG3 number 1-3 
  IN OTX_UINT32            nTug2Number,  // @parm TUG2 number 1-7 
  IN OtxTemuxTug2PayloadE  eTug2Payload  // @parm TUG2 configuration 
);

/*******************************************************************************

  @func
    SONET/SDH Subsystem configuration on the Temux 336/168 this function 
    configures the LOPP and LOPP_TX subsystems VT-Group payload type.

  @comm
    This function will set all other R/W bits to 0 when the payload 
    configuration is set.  Seperate functions will need  to configure 
    the interrupt enables for the TUG-2

  @ex |

  @xref
    <t OtxTemuxVtTypeE>


*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxVtGroupPayloadCfg(
  IN OTX_HANDLE       hDevice,         // @parm A handle to a Temux device.
  IN OTX_UINT32       nLink,           // @parm Link Slice 1-4
                                       //<nl>  1   STSI HOPP STS-3/STM-1 #1  
                                       //<nl>  2   STSI HOPP STS-3/STM-1 #2 
                                       //<nl>  3   STSI HOPP STS-3/STM-1 #3 
                                       //<nl>  4   STSI HOPP STS-3/STM-1 #4
  IN OTX_UINT32       nStm1Number,     // @parm STS number 1-3 
  IN OTX_UINT32       nVtGroupNumber,  // @parm VT Group number 1-7 
  IN OtxTemuxVtTypeE  eVtGroupPayload  // @parm VT-2 (E1) or VT-1.5 (T1)
);

/*******************************************************************************

  @func
    SONET/SDH Subsystem configuration on the Temux 336/168 this function 
    configures the LOPP_TX TVPTA bypassing. 

  @comm
    The TVTPA must not be bypassed if the VT2/TU-12 or VT1.5/TU-11 
    has byte synchronous mapping or is a TVT. The TVTPA is bypassed 
    at an STS-1 level.

  @ex |

  @xref
    <t OtxTemuxBypassE>


*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxTvtpaBypassCfg(
  IN OTX_HANDLE       hDevice,        // @parm A handle to a Temux device.
  IN OTX_UINT32       nLink,          // @parm Link Slice 1-4
                                      //<nl>  1   STSI HOPP STS-3/STM-1 #1  
                                      //<nl>  2   STSI HOPP STS-3/STM-1 #2 
                                      //<nl>  3   STSI HOPP STS-3/STM-1 #3 
                                      //<nl>  4   STSI HOPP STS-3/STM-1 #4
  IN OTX_UINT32       nStm1Number,    // @parm STS number 1-3 
  IN OtxTemuxBypassE  eBypassBar      // @parm Bypassed or Not Bypassed
);


/*******************************************************************************

  @func
    PDH Subsystem data path configuration on the Temux 336/168 this function 
    configures the operation mode for the PDH subsystem system side interface. 
    In addition, it configures user input parameters associated with the 
    respective interface.

  @comm
    The param1 to param5 vary depending on the selected sysIfMode.  
    Legal values for parameters param1 - param5 are 0 or 1.  
    The not applicable (N/A) parameters is set to 0.

    See table in example section 

    <nl>SBI (0) = eSysIfMode:

      In SBI mode of operation Register 0x61 software scratch register will 
      be used to track the configuration of ADD_TVT_EN and DROP_TVT_EN bits.
      
      DRVHOLD (Param1) - HW dependent. 
                Typically set to 1 for point to point SBI bus connection.
                This setting assumes that TEMUX 336 is the only device on 
                the phy side of the SBI Drop Bus.

      SBI_PAR_CTL (Param2) - Specifies the bus parity for TVT mode tributaries
                    that are passed across the SBI bus.
                    0 - even parity is selected
                    1 - odd parity is selected

      MFSDC1FP (Param3) -
                 0 - Asynchronous SBI Frame Pulse 1 pulse every 4 SBI frames
                     125 us frames
                 1 - Synchronous SBI Frame Pulse 1 pulse every 48 SBI frames

      SDC1FPM (Param4) - HW dependent. 
                0 - TEMUX 336 uses SBI SDC1FP signal as an input

      TVT_EN (Param5) - Configures the devices ability to 
               operate TVT mode tributaries:
               0 - TVT tributaries may not be configured
               1 - TVT tributaries may be configured

    <nl>SBI-TR (1) = eSysIfMode:

      C1FPM  (Param1) - Dependent on intended SBITR bus operation (0)

      SYNCM  (Param2) - Dependent on intended SBITR bus operation (0)

    <nl>HMVIP (2) = eSysIfMode:

      HMVIP_TFALL (Param2) - (0)

      HMVIP_RFALL (Param3) - (0)

  @ex |
    
    System
    Interface | Param1 | Param2      | Param3     | Param4  | Param5
    ----------+--------+-------------+------------+---------+--------
    SBI    (0)| DRVHOLD| SBI_PAR_CTRL| MFSDC1FP   | SDC1FPM | TVT_EN
    SBI-TR (1)| C1FPM  | SYNCM       | N/A        | N/A     | N/A 
    HMVIP  (2)| N/A    | HMVIP_TFALL | HMVIP_RFALL| N/A     | N/A 


  @xref
    <t OtxTemuxSysIfMode>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxSysIfModeCfg(
  IN OTX_HANDLE        hDevice,    // @parm A handle to a Temux device.
  IN OtxTemuxSysIfMode eSysIfMode, // @parm System side (0-SBI 1-SBI-TR 2-HMVIP)
  IN OTX_BOOL          nParam1,    // @parm Dependent on eSysIfMode
  IN OTX_BOOL          nParam2,    // @parm Dependent on eSysIfMode
  IN OTX_BOOL          nParam3,    // @parm Dependent on eSysIfMode
  IN OTX_BOOL          nParam4,    // @parm Dependent on eSysIfMode
  IN OTX_BOOL          nParam5     // @parm Dependent on eSysIfMode
);


/*******************************************************************************

  @func
    PDH Subsystem data path configuration on the Temux 336/168 this function 
    configures an SPE of the Mapper subsystem.

  @comm

  @ex |

  @xref
    <t OtxTemuxMapSpeSrc>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxMapperSpeCfg(
  IN OTX_HANDLE         hDevice,      // @parm A handle to a Temux device.
  IN OTX_UINT32         nSliceNumber, // @parm Mapper block instance: 1-4
  IN OTX_UINT32         nSpeNumber,   // @parm SPE number: 1-3
  IN OtxTemuxMapSpeSrc  eMapSpeSrc    // @parm T1E1 or DS3E3 subsystem
);


/*******************************************************************************

  @func
    PDH Subsystem data path configuration on the Temux 336/168 this function 
    configures a T1 or E1 tributary for mapping to SONET/SDH. The supported 
    mapping types are bit asynchronous, byte synchronous, or transparent 
    virtual tributary (TVT).

  @comm

    This function configures a T1 or E1 tributary for mapping to SONET/SDH. 
    The supported mapping types are bit asynchronous, byte synchronous, or 
    transparent virtual tributary.

    If a tributary is configured for byte synchronous mapping or is a TVT, 
    the LOPP_TX TVTPA cannot be bypassed. For byte synchronous or transparent 
    virtual tributaries ensure that the function OtxTemuxTvtpaBypassCfg is 
    called to not bypass the TVTPA for the STS-1 associated with the 
    tributary prior to configuring any byte synchronous tributaries 
    <f OtxTemuxTvtpaBypassCfg>.

  @devnote
    Prior to calling this function the payload type (T1 or E1) of the T1E1 
    and Mapper subsystems for this SPE needs to be configured 
    <f  OtxTemuxE1T1SpeCfg>.

  @ex |

  @xref
    <t OtxTemuxMapTribMode>
    <t OtxTemuxPhdTrib>
    <t OtxTemuxVtTypeE>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxMapperTribCfg(
  IN OTX_HANDLE              hDevice,       // @parm A handle to a Temux device.
  IN OTX_UINT32              nSliceNumber,  // @parm Mapper block instance 1-4
  IN OTX_UINT32              nSpeNumber,    // @parm SPE number 1-3
  IN OTX_UINT32              nTribNumber,   // @parm T1/E1 tributary number: 
                                            //<nl>   1-28 T1 mode  
                                            //<nl>   1-21 E1 mode
  IN OtxTemuxMapTribMode     eMapTribMode,  // @parm T1/E1 tributary mapping
  IN OtxTemuxPhdTrib         ePhdTribType,  // @parm PDH tributary type
  IN OtxTemuxVtTypeE         eSonetTribType // @parm virtual tributaries type
);


/*******************************************************************************

  @func
    PDH Subsystem data path configuration on the Temux 336/168 this function 
    configures an MX13 SPE for the type of tributaries (T1 or E1) that are 
    multiplexed to a DS3 and the framing format of the DS3 frame. The seven 
    T2s associated with the MX13 SPE will also be configured for T1 or E1 
    mode of operation.

  @comm

  @ex |

  @xref
    <t OtxTemuxPhdTrib>
    <t OtxTemuxDs3FrameType>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxMx13SpeCfg(
  IN OTX_HANDLE            hDevice,      // @parm A handle to a Temux device.
  IN OTX_UINT32            nSpeNumber,   // @parm MX13 SPE number 0-11
  IN OtxTemuxPhdTrib       ePhdTribType, // @parm PDH tributary type
  IN OtxTemuxDs3FrameType  eDs3FrameType // @parm DS3 frame type M23 or Cbit parity
);


/*******************************************************************************

  @func
    PDH Subsystem data path configuration on the Temux 336/168 this function 
    specifies the ingress and egress data stream source for an SPE of the 
    DS3E3 subsystem.

  @comm
    The ingress data stream can be received from the DS3E3MD demapper block 
    or the line side DS3/E3 serial interface. The egress data stream can be 
    sourced from the MX13 subsystem, the system side DS3/E3 payload interface 
    or the SBI bus. The data can only be sourced from the SBI bus when the 
    system interface is configured for SBI mode of operation.
    
    Calling this function will disable all loopbacks associated with the 
    DS3E3 subsystem. The disabled loopbacks are the egress auxiliary loopback 
    (EGRESSAUXLBSEL), the DS3E3MD line side loopback (MAPPERSEL) and the 
    DS3E3FRMR loopback (DS3E3_TRANSEL[1:0]).

  @ex |

  @xref
    <t OtxTemuxIngressSrc>
    <t OtxTemuxEgressSrc>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxD3E3SpeDataPathCfg(
  IN OTX_HANDLE             hDevice,         // @parm A handle to a Temux device.
  IN OTX_UINT32             nSpeNumber,      // @parm DS3E3 SPE number 0-11
  IN OtxTemuxIngressSrc     eIngressSource,  // @parm Ingress data source
  IN OtxTemuxEgressSrc      eEgressSource    // @parm Egress data source 
);


/*******************************************************************************

  @func
    PDH Subsystem data path configuration on the Temux 336/168 this function 
    configures the DS3E3 subsystem for the type of DS3/E3 frame being used. 

  @comm
    It should be noted that for E3 mode of operation, only G.751 and 
    unframed/clear channel modes of operation are supported over the SBI bus.

   <nl>0. DS3 - unframed/clearchannel
   <nl>1. E3  - unframed/clearchannel
   <nl>2. DS3 - C-bit parity
   <nl>3. DS3 - M23 framing
   <nl>4. E3  - G.751
   <nl>5. E3  - G.832

  @ex |

  @xref
    <t OtxTemuxDs3e3Frame>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxD3E3SpeFrameCfg(
  IN OTX_HANDLE             hDevice,        // @parm A handle to a Temux device.
  IN OTX_UINT32             nSpeNumber,     // @parm DS3E3 SPE number 0-11
  IN OtxTemuxDs3e3Frame     eDs3e3FrameType // @parm Ingress data source
);

/*******************************************************************************

  @func
    PDH Subsystem data path configuration on the Temux 336/168 this function 
    is only required if the DS3/E3 serial line side interface is used. This 
    function enables or disables the specified LIU signals and configures the 
    DS3 or E3 transmitter and receiver for unipolar or bipolar modes of operation.

  @comm

  @devnote
    Only required if the DS3/E3 serial line side interface.

  @ex |

  @xref
    <t OtxTemuxDs3e3Mode>
    <t OtxTemuxSignalPolarity>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxD3E3SpeLineIfCfg(
  IN OTX_HANDLE             hDevice,    // @parm A handle to a Temux device.
  IN OTX_UINT32             nSpeNumber, // @parm SPE number of the LIU 0-11
  IN OtxTemuxDs3e3Mode      eDs3e3Mode, // @parm Format associated with the LIU DS3/E3
  IN OtxTemuxSignalPolarity eBipolar,   // @parm Transmit and receive LIU signal polarity
  IN OTX_BOOL               bEnable     // @parm DS3/E3 Line Interface LIU port enabling
                                        //<nl>   0-disabled  1-enabled
);

/*******************************************************************************

  @func
    This function configures the timing mode for a DS3/E3 link.

  @comm
    There are five possible timing modes.
    <nl>0 -  SBI Egress Data Rate
    <nl>1 -  Link Rate Octet
    <nl>2 -  TICLK
    <nl>3 -  DS3REFCLK/E3REFCLK
    <nl>4 -  DS3/E3 Recovered Clock

    Options SBI Egress Data Rate (0) and Link Rate Octet (1) may only be selected 
    if the DS3/E3 payload is being transferred across the SBI interface. All other 
    options are valid for both system side SBI bus and system side DS3/E3 payload 
    interface.

  @ex |

  @xref
    <t OtxTemuxTimingMode>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxD3E3SpeTimingCfg(
  IN OTX_HANDLE         hDevice,    // @parm A handle to a Temux device.
  IN OTX_UINT32         nSpeNumber, // @parm SPE slice number of DS3/E3 0-11
  IN OtxTemuxTimingMode eClockSrc   // @parm Egress DS3/E3 timing source
);

/*******************************************************************************

  @func
    PDH Subsystem data path configuration on the Temux 336/168 this function 
    enables or disables a tributary on the SBI bus that carries DS3 or E3 
    payload. It also configures the payload type for the SPE. 
    

  @comm
    Options SBI Egress Data Rate (0) and Link Rate Octet (1) may only be  
    selected if the DS3/E3 payload is being transferred across the SBI 
    interface. 
    <f OtxTemuxD3E3SpeTimingCfg>

  @devnote
    This function is only required if DS3 or E3 payload data is transferred 
    across the SBI bus. 
    <f OtxTemuxD3E3SpeDataPathCfg>

  @ex |

  @xref
    <t OtxTemuxPayload>
    <t OtxTemuxTimingMode>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxD3E3SpeSbiCfg(
  IN OTX_HANDLE         hDevice,      // @parm A handle to a Temux device.
  IN OTX_UINT32         nSliceNumber, // @parm SBI INSBI/EXSBI block slice 1-4
  IN OTX_UINT32         nSpeNumber,   // @parm SPE slice number of DS3/E3 0-11
  IN OtxTemuxPayload    ePayloadType, // @parm DS3/E3 payload type
  IN OTX_BOOL           bEnable,      // @parm DS3/E3 INSBI/EXSBI tributary enable
                                      //<nl>   0- disabled  1- enabled
  IN OtxTemuxTimingMode eClockSrc     // @parm Egress DS3/E3 timing source
                                      //<nl>   0 - SBI Egress Data Rate   
                                      //<nl>   1 - Link Rate Octet
);

/*******************************************************************************

  @func
    PDH Subsystem data path configuration on the Temux 336/168 this function 
    configures the payload type and data path for the E1T1 subsystem. The 
    user must specify the system interface that has been configured 
    (SBI, SBITR or HMVIP) as an input to this function as the SPE level 
    configuration varies depending on the system side interface used. 

  @comm
    This function must be called before <f OtxTemuxMapperTribCfg> as it 
    sets the SPE payload used by the Mapper and E1T1 subsystem.

  @ex |

  @xref
    <t OtxTemuxSysIfMode>
    <t OtxTemuxSpeDest>
    <t OtxTemuxPhdTrib>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxE1T1SpeCfg(
  IN OTX_HANDLE        hDevice,     // @parm A handle to a Temux device.
  IN OTX_UINT32        nSliceNumber,// @parm E1T1 subsystem slice instance 1-4
  IN OTX_UINT32        nSpeSliceNum,// @parm SPE instance in slice of E1T1 1-3
  IN OtxTemuxSysIfMode eSysIfMode,  // @parm System interface mode of operation
  IN OtxTemuxSpeDest   eSpeDest,    // @parm Data path configuration
  IN OtxTemuxPhdTrib   ePhdTribType // @parm PDH tributary type T1/E1
 );

/*******************************************************************************

  @func
    PDH Subsystem data path configuration on the Temux 336/168 this 
    function configures the framing type used by a T1 or E1 tributary 
    in the E1T1 subsystem.

  @comm
    T1 framing modes (Unframed, ESF, SF) can only be used when the SPE is 
    configured for T1 mode of operation. E1 framing modes (Unframed, Standard, 
    CRC, CAS, CAS + CRC) can only be used when the SPE is configured for E1 
    mode of operation <f OtxTemuxTmx336E1T1SpeCfg>. 
    
    Unframed T1/E1 only supported with SBI or SBITR system side interface.

  @ex |

  @xref
    <t OtxTemuxFrameMode>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxE1T1TribFrameCfg(
  IN OTX_HANDLE        hDevice,      // @parm A handle to a Temux device.
  IN OTX_UINT32        nSliceNumber, // @parm E1T1 subsystem slice instance 1-4
  IN OTX_UINT32        nSpeSliceNum, // @parm SPE instance E1T1 subsystem 1-3
  IN OTX_UINT32        nTribNumber,  // @parm T1/E1 tributary number: 
                                     //<nl>   1-28 T1 mode  
                                     //<nl>   1-21 E1 mode
  IN OtxTemuxFrameMode eFrameMode    // @parm T1/E1 framing mode
);

/*******************************************************************************

  @func
    PDH Subsystem data path configuration on the Temux 336/168 this function 
    configures the timing for an ingress T1 or E1 rate tributary.

  @comm

  @devnote
    This function is only required if T1 or E1 payload data is transferred 
    across the SBI bus. 

  @ex |

  @xref
    <t OtxTemuxELST>
    <t OtxTemuxRxTiming>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxE1T1IngressTribTimingCfg(
  IN OTX_HANDLE        hDevice,      // @parm A handle to a Temux device.
  IN OTX_UINT32        nSliceNumber, // @parm E1T1 subsystem slice instance 1-4
  IN OTX_UINT32        nSpeSliceNum, // @parm SPE instance E1T1 subsystem 1-3
  IN OTX_UINT32        nTribNumber,  // @parm T1/E1 tributary number: 
                                     //<nl>   1-28 T1 mode  
                                     //<nl>   1-21 E1 mode
  IN OtxTemuxELST      eBypassMode,  // @parm RX_ELST Ingress elastic buffer
  IN OtxTemuxRxTiming  eTiming       // @parm Ingress tributary timing mode
);

/*******************************************************************************

  @func
    PDH Subsystem data path configuration on the Temux 336/168 this function 
    configures the timing for an egress T1 or E1 rate tributary.

  @comm

  @devnote
    This function is only required if T1 or E1 payload data is transferred 
    across the SBI bus. 

  @ex |

  @xref
    <t OtxTemuxELST>
    <t OtxTemuxTxTiming>
    <t OtxTemuxMapTribMode>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxE1T1EgressTribTimingCfg(
  IN OTX_HANDLE          hDevice,     // @parm A handle to a Temux device.
  IN OTX_UINT32          nSliceNumber,// @parm E1T1 subsystem slice instance 1-4
  IN OTX_UINT32          nSpeSliceNum,// @parm SPE instance E1T1 subsystem 1-3
  IN OTX_UINT32          nTribNumber, // @parm T1/E1 tributary number: 
                                      //<nl>   1-28 T1 mode  
                                      //<nl>   1-21 E1 mode
  IN OtxTemuxELST        eBypassMode, // @parm TX_ELST egress elastic buffer
  IN OtxTemuxTxTiming    eTiming,     // @parm egress tributary timing mode
                                      //<nl> If timing information from system 
                                      //<nl> side interface (3) or transmux (4) 
                                      //<nl> mode is used, 'bypass' must be 1.
  IN OtxTemuxMapTribMode eSrcOrDest   // @parm Type of Tributary being Timed:
                                      //<nl>   0 - Bit asynchronous mapped
                                      //<nl>   1 - Byte synchronous mapped
                                      //<nl>   2 - Multiplexed to DS3
);

/*******************************************************************************

  @func
    PDH Subsystem data path configuration on the Temux 336/168 this function 
    enables or disables a tributary on the SBI bus that is caring a T1 or E1 
    payload. It also configures the payload type for the SPE. 

  @comm

  @devnote
    This function is only required if T1 or E1 payload data is transferred 
    across the SBI bus. 

  @ex |

  @xref
    <t OtxTemuxSync>
    <t OtxTemuxMode>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxE1T1TribSbiCfg(
  IN OTX_HANDLE   hDevice,     // @parm A handle to a Temux device.
  IN OTX_UINT32   nSliceNumber,// @parm SBI subsystem slice instance 1-4
  IN OTX_UINT32   nSpeSliceNum,// @parm SPE instance SBI subsystem 1-3
  IN OTX_UINT32   nTribNumber, // @parm T1/E1 tributary number: 
                               //<nl>   1-28 T1 mode  
                               //<nl>   1-21 E1 mode
  IN OtxTemuxSync eSyncTrib,   // @parm Tributary synchronous or asynchronous
                               // on SBI Add/Drop bus
  IN OTX_BOOL     bEnable,     // @parm T1E1 tributary 0-disabled, 1-enabled
  IN OtxTemuxMode eRateMode    // @parm Tributary T1/E1 or TVT on SBI Add/Drop bus
);


/*******************************************************************************

  @func
    Utility function used during device initalization. This function perform
    a device reset base initialization and is the first function caller before
    the device is configured.

  @comm

  @devnote
    Needs to be called first to start device initialization.

  @ex |

  @xref

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxInitialize(
  IN OTX_HANDLE   hDevice     // @parm A handle to a Temux device.
);

/*******************************************************************************

  @func
    Utility function used to get status of the Line Interface (Li)

  @comm


  @ex |

  @xref

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxGetLiStatus(
  IN OTX_HANDLE             hDevice,    // @parm A handle to a Temux device.
  OUT OtxTemuxGetLiStatusS  *pLiStatus  // @parm Li status
);

/*******************************************************************************

  @func
    Utility function used to get status of the Temux device

  @comm


  @ex |

  @xref

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxTemuxGetInfo(
  IN OTX_HANDLE             hDevice,     // @parm A handle to a Temux device.
  OUT OtxTemuxGetTemuxInfoS *pTemuxInfo  // @parm Information connected to Temux
);

#ifdef __cplusplus
}  // extern "C"
#endif

/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 2010


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif  // OTX_TEMUX_H
